# Glow - Renderizador de Markdown para Terminal

## Introducción

[Glow](https://github.com/charmbracelet/glow) es un potente renderizador de Markdown para terminal desarrollado por [Charm](https://charm.sh/). Esta herramienta permite visualizar y trabajar con documentos Markdown directamente en la línea de comandos, con soporte para temas, paginación y otras características avanzadas.

## Instalación

En MRDevs Tools, Glow se instala automáticamente como parte del proceso de bootstrap:

```bash
# Instalación de todas las herramientas base (incluye Glow)
bin/bootstrap.sh
```

También puedes actualizarlo con:

```bash
# Actualización del entorno (incluye Glow)
bin/update.sh
```

## Características Principales

- **Renderizado de alta calidad**: Visualiza documentos Markdown con estilos y formato consistentes
- **Soporte para temas**: Incluye temas claro, oscuro y personalizados
- **Modo paginado**: Facilita la lectura de documentos extensos
- **Vista local y remota**: Capacidad para mostrar archivos locales o desde repositorios remotos
- **Navegación mejorada**: Controles intuitivos para navegar entre secciones

## Uso Básico

### Visualizar un Archivo Markdown

Para visualizar un archivo Markdown local:

```bash
glow README.md
```

### Modo Paginado para Archivos Largos

```bash
glow -p LICENSE.md
```

### Seleccionar un Tema

```bash
# Tema oscuro
glow -s dark README.md

# Tema claro
glow -s light README.md
```

### Ajustar el Ancho del Contenido

```bash
# Establecer un ancho personalizado (en caracteres)
glow -w 100 README.md
```

## Comandos Avanzados

### Leer un Archivo Markdown Remoto

```bash
# Desde un repositorio GitHub
glow https://github.com/charmbracelet/glow/blob/master/README.md

# Desde una URL directa
glow https://raw.githubusercontent.com/charmbracelet/glow/master/README.md
```

### Usar Glow en Modo Explorador

El modo explorador te permite navegar por todos los archivos Markdown en un directorio:

```bash
glow -l
```

### Personalizar Estilos

```bash
# Ajustar el estilo de los encabezados
glow -s dark --header-fg "#FF5F87" README.md

# Ajustar el color de fondo
glow -s dark --background "#111111" README.md
```

## Integración con MRDevs Tools

MRDevs Tools aprovecha Glow en diversos componentes:

1. **Documentación del Proyecto**: Glow es la herramienta recomendada para consultar la documentación del proyecto
2. **Visualización de README**: Facilita la lectura de archivos README de proyectos creados con `project_new.sh`
3. **Información de Ayuda**: Los scripts internos pueden mostrar información de ayuda en formato Markdown

### Ejemplo de Script que Integra Glow

```bash
#!/bin/bash
# Ejemplo de integración de Glow en un script

# Detectar si Glow está disponible
if command -v glow >/dev/null 2>&1; then
    RENDER_CMD="glow -"
else
    # Fallback si Glow no está disponible
    RENDER_CMD="cat"
fi

# Generar documentación en formato Markdown
cat << EOF | $RENDER_CMD
# Título del Documento

## Secciones
- Sección 1
- Sección 2

## Código de Ejemplo
\`\`\`bash
echo "Hola Mundo"
\`\`\`
EOF
```

## Configuración Personalizada

Puedes configurar Glow mediante un archivo de configuración:

```bash
# Crear una configuración inicial
mkdir -p ~/.config/glow
cat > ~/.config/glow/glow.yml << EOF
# Configuración de Glow
style: dark
pager: true
width: 80
EOF
```

## Consejos y Trucos

1. **Combinar con Gum**: Utiliza Glow junto con [Gum](gum.md) para crear interfaces TUI completas
   ```bash
   glow README.md | gum pager
   ```

2. **Vista rápida de archivos**: Establece un alias para previsualizar rápidamente archivos Markdown
   ```bash
   alias mdview='glow -p'
   ```

3. **Exportar a HTML**: Puedes convertir Markdown a HTML para otros usos
   ```bash
   glow -f html README.md > readme.html
   ```

## Resolución de Problemas

### Problemas con Colores
Si los colores no se muestran correctamente, asegúrate de que tu terminal soporte 256 colores o true color:
```bash
export TERM=xterm-256color
```

### Problemas de Paginación
Si experimentas problemas con el paginador:
```bash
# Usar un paginador alternativo
PAGER=less glow -p README.md
```

## Recursos Adicionales

- [Documentación oficial de Glow](https://github.com/charmbracelet/glow)
- [Charm.sh](https://charm.sh/) - Sitio oficial del desarrollador
- [Markdown Guide](https://www.markdownguide.org/) - Guía completa de Markdown

---

Creado por Cortana Rosero One para MRDevs Tools.
Última actualización: 2025/04/07